# -*- coding: utf-8 -*-
"""
Create, Read, Update, Delete functionality

"""

from sqlalchemy import cast, Text
from typing import List
from geoalchemy2.types import Geometry
from sqlalchemy.orm import Session
from sqlalchemy.dialects.postgresql import JSONB, ARRAY
from fastapi import File, UploadFile
from fastapi.responses import JSONResponse
from fastapi.encoders import jsonable_encoder
from . import models
from .schemas import get_coordinates_from_geom, get_geom_from_coordinates, StationmetaCoreCreate, Coordinates
from pydantic import ValidationError


def get_stationmeta_core(db: Session, station_code: str):
    db_object = db.query(models.StationmetaCore).filter(cast(models.StationmetaCore.codes,Text).contains(station_code.strip())).first()
    # there is a mismatch with coordinates and additional_metadata
    if db_object:
        db_object.coordinates = get_coordinates_from_geom(db_object.coordinates)
        db_object.additional_metadata = str(db_object.additional_metadata)
    return db_object


def get_all_stationmeta_core(db: Session, skip : int = 0, limit: int = None):
    db_objects = db.query(models.StationmetaCore).offset(skip).limit(limit).all()
    for db_object in db_objects:
        # there is a mismatch with coordinates and additional_metadata
        db_object.coordinates = get_coordinates_from_geom(db_object.coordinates)
        db_object.additional_metadata = str(db_object.additional_metadata)
    return db_objects


def create_stationmeta_core(db: Session, stationmeta_core: StationmetaCoreCreate):
    db_stationmeta_core = models.StationmetaCore(**stationmeta_core.dict())
    # there's a mismatch with coordinates --> how to automatically switch back and forth?!
    tmp_coordinates = db_stationmeta_core.coordinates
    db_stationmeta_core.coordinates = get_geom_from_coordinates(Coordinates(**db_stationmeta_core.coordinates))
    # there's also a mismatch with additional_metadata --> BUT: this should not be switched back!
    # in upload command, we have now: "additional_metadata": "{}"
    # but return from this method gives: "additional_metadata": {}
    # ==> there is a mismatch between model(JSONB) and schema(JSON)
    db_stationmeta_core.additional_metadata = str(db_stationmeta_core.additional_metadata)
    db.add(db_stationmeta_core)
    result = db.commit()
    db.refresh(db_stationmeta_core)
    # there's a mismatch with coordinates --> how to automatically switch back and forth?!
    db_stationmeta_core.coordinates = tmp_coordinates
    return db_stationmeta_core
