# coding: utf-8
"""
class StationmetaRole (Base)
============================
"""
from sqlalchemy import Column, ForeignKey, Integer, text, \
                       CheckConstraint, UniqueConstraint
#from sqlalchemy.orm import relationship
from sqlalchemy.ext.declarative import declarative_base
from toardb.contacts.models import Person
from .models_core import StationmetaCore

Base = declarative_base()
metadata = Base.metadata

class StationmetaRole(Base):
    """ Table "public.stationmeta_roles"

    +------------+---------+-----------+----------+-------------------------------------------+
    |   Column   |  Type   | Collation | Nullable |                  Default                  |
    +============+=========+===========+==========+===========================================+
    | id         | integer |           | not null | nextval('station_roles_id_seq'::regclass) |
    +------------+---------+-----------+----------+-------------------------------------------+
    | role       | integer |           | not null |                                           |
    +------------+---------+-----------+----------+-------------------------------------------+
    | status     | integer |           | not null |                                           |
    +------------+---------+-----------+----------+-------------------------------------------+
    | person_id  | integer |           | not null |                                           |
    +------------+---------+-----------+----------+-------------------------------------------+
    | station_id | integer |           | not null |                                           |
    +------------+---------+-----------+----------+-------------------------------------------+
    Indexes:
     "stationmeta_roles_pkey" PRIMARY KEY, btree (id)
     "stationmeta_roles_station_id_role_person_id_29a832af_uniq" UNIQUE CONSTRAINT, btree (station_id, role, person_id)
     "stationmeta_roles_person_id_3bd9c160" btree (person_id)
     "stationmeta_roles_station_id_f31f80fc" btree (station_id)
    Check constraints:
     "stationmeta_roles_role_check" CHECK (role >= 0)
     "stationmeta_roles_status_check" CHECK (status >= 0)
    Foreign-key constraints:
     "stationmeta_roles_person_id_3bd9c160_fk_persons_id" FOREIGN KEY (person_id) REFERENCES persons(id) DEFERRABLE INITIALLY DEFERRED
     "stationmeta_roles_station_id_f31f80fc_fk_stationmeta_core_id" FOREIGN KEY (station_id) REFERENCES stationmeta_core(id) DEFERRABLE INITIALLY DEFERRED
    """

    __tablename__ = 'stationmeta_roles'
    __table_args__ = (
        CheckConstraint('role >= 0'),
        CheckConstraint('status >= 0'),
        UniqueConstraint('station_id', 'role', 'person_id')
    )

    id = Column(Integer, primary_key=True, server_default=text("nextval('stationmeta_roles_id_seq'::regclass)"))
    role = Column(Integer, nullable=False)
    status = Column(Integer, nullable=False)
# do not use string declaration here (not working for pytest)
# use the explicit class name here,
# see: https://groups.google.com/forum/#!topic/sqlalchemy/YjGhE4d6K4U
    person_id = Column(ForeignKey(Person.id, deferrable=True, initially='DEFERRED'), nullable=False, index=True)
    station_id = Column(ForeignKey(StationmetaCore.id, deferrable=True, initially='DEFERRED'), nullable=False, index=True)
# how to reactivate the following two lines?!
#   person = relationship('Person')
#   station = relationship('Station')

