# coding: utf-8
"""
class TimeseriesAnnotation(Base)
================================
"""
from sqlalchemy import Column, DateTime, Float, ForeignKey, Integer, text, String, \
                       Text, Boolean, CheckConstraint
#from sqlalchemy.orm import relationship
from sqlalchemy.ext.declarative import declarative_base
from toardb.auth_user.models import AuthUser
from .models_core import Timeseries

Base = declarative_base()
metadata = Base.metadata

class TimeseriesAnnotation(Base):
    """ Table "public.timeseries_annotations"

    +----------------+--------------------------+-----------+----------+----------------------------------------------------+
    |     Column     |           Type           | Collation | Nullable |                      Default                       |
    +================+==========================+===========+==========+====================================================+
    | id             | integer                  |           | not null | nextval('timeseries_annotations_id_seq'::regclass) |
    +----------------+--------------------------+-----------+----------+----------------------------------------------------+
    | kind           | integer                  |           | not null |                                                    |
    +----------------+--------------------------+-----------+----------+----------------------------------------------------+
    | text           | text                     |           | not null |                                                    |
    +----------------+--------------------------+-----------+----------+----------------------------------------------------+
    | date_added     | timestamp with time zone |           | not null |                                                    |
    +----------------+--------------------------+-----------+----------+----------------------------------------------------+
    | approved       | boolean                  |           | not null |                                                    |
    +----------------+--------------------------+-----------+----------+----------------------------------------------------+
    | contributor_id | integer                  |           | not null |                                                    |
    +----------------+--------------------------+-----------+----------+----------------------------------------------------+
    | timeseries_id  | integer                  |           | not null |                                                    |
    +----------------+--------------------------+-----------+----------+----------------------------------------------------+
    Indexes:
        "timeseries_annotations_pkey" PRIMARY KEY, btree (id)
        "timeseries_annotations_contributor_id_7a1758f6" btree (contributor_id)
        "timeseries_annotations_timeseries_id_02014000" btree (timeseries_id)
    Check constraints:
        "timeseries_annotations_kind_check" CHECK (kind >= 0)
    Foreign-key constraints:
        "timeseries_annotations_contributor_id_7a1758f6_fk_auth_user_id" FOREIGN KEY (contributor_id) REFERENCES auth_user(id) DEFERRABLE INITIALLY DEFERRED
        "timeseries_annotations_timeseries_id_02014000_fk_timeseries_id" FOREIGN KEY (timeseries_id) REFERENCES timeseries(id) DEFERRABLE INITIALLY DEFERRED
    """
    __tablename__ = 'timeseries_annotations'
    __table_args__ = (
        CheckConstraint('kind >= 0'),
    )

    id = Column(Integer, primary_key=True, server_default=text("nextval('timeseries_annotations_id_seq'::regclass)"))
    kind = Column(Integer, nullable=False)
    text = Column(Text, nullable=False)
    date_added = Column(DateTime(True), nullable=False)
    approved = Column(Boolean, nullable=False)
# do not use string declaration here (not working for pytest)
# use the explicit class name here,
# see: https://groups.google.com/forum/#!topic/sqlalchemy/YjGhE4d6K4U
    contributor_id = Column(ForeignKey(AuthUser.id, deferrable=True, initially='DEFERRED'), nullable=False, index=True)
    timeseries_id = Column(ForeignKey(Timeseries.id, deferrable=True, initially='DEFERRED'), nullable=False, index=True)
# how to reactivate the following two lines?!
#   contributor = relationship('AuthUser')
#   timeseries = relationship('Timeseries')
