# coding: utf-8
"""
class TimeseriesRole (Base)
===========================
"""
from sqlalchemy import Column, ForeignKey, Integer, text, \
                       CheckConstraint, UniqueConstraint
#from sqlalchemy.orm import relationship
from sqlalchemy.ext.declarative import declarative_base
from toardb.contacts.models import Person
from .models_core import Timeseries

Base = declarative_base()
metadata = Base.metadata

class TimeseriesRole(Base):
    """ Table "public.timeseries_roles"

    +---------------+---------+-----------+----------+----------------------------------------------+
    |    Column     |  Type   | Collation | Nullable |                   Default                    |
    +===============+=========+===========+==========+==============================================+
    | id            | integer |           | not null | nextval('timeseries_roles_id_seq'::regclass) |
    +---------------+---------+-----------+----------+----------------------------------------------+
    | role          | integer |           | not null |                                              |
    +---------------+---------+-----------+----------+----------------------------------------------+
    | status        | integer |           | not null |                                              |
    +---------------+---------+-----------+----------+----------------------------------------------+
    | person_id     | integer |           | not null |                                              |
    +---------------+---------+-----------+----------+----------------------------------------------+
    | timeseries_id | integer |           | not null |                                              |
    +---------------+---------+-----------+----------+----------------------------------------------+
    Indexes:
        "timeseries_roles_pkey" PRIMARY KEY, btree (id)
        "timeseries_roles_timeseries_id_role_person_id_d888d4bf_uniq" UNIQUE CONSTRAINT, btree (timeseries_id, role, person_id)
        "timeseries_roles_person_id_3e26200e" btree (person_id)
        "timeseries_roles_timeseries_id_13b7edfd" btree (timeseries_id)
    Check constraints:
        "timeseries_roles_role_check" CHECK (role >= 0)
        "timeseries_roles_status_check" CHECK (status >= 0)
    Foreign-key constraints:
        "timeseries_roles_person_id_3e26200e_fk_persons_id" FOREIGN KEY (person_id) REFERENCES persons(id) DEFERRABLE INITIALLY DEFERRED
        "timeseries_roles_timeseries_id_13b7edfd_fk_timeseries_id" FOREIGN KEY (timeseries_id) REFERENCES timeseries(id) DEFERRABLE INITIALLY DEFERRED
    """

    __tablename__ = 'timeseries_roles'
    __table_args__ = (
        CheckConstraint('role >= 0'),
        CheckConstraint('status >= 0'),
        UniqueConstraint('timeseries_id', 'role', 'person_id')
    )

    id = Column(Integer, primary_key=True, server_default=text("nextval('timeseries_roles_id_seq'::regclass)"))
    role = Column(Integer, nullable=False)
    status = Column(Integer, nullable=False)
# do not use string declaration here (not working for pytest)
# use the explicit class name here,
# see: https://groups.google.com/forum/#!topic/sqlalchemy/YjGhE4d6K4U
    person_id = Column(ForeignKey(Person.id, deferrable=True, initially='DEFERRED'), nullable=False, index=True)
    timeseries_id = Column(ForeignKey(Timeseries.id, deferrable=True, initially='DEFERRED'), nullable=False, index=True)
# how to reactivate the following two lines?!
#   person = relationship('Person')
#   timeseries = relationship('Timeseries')

